CREATE TABLE Collective (
    ID BIGINT PRIMARY KEY GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1), 
    Name VARCHAR(64) NOT NULL UNIQUE, 
    Type VARCHAR(20) NOT NULL, 
    MAXCAPONMEMBERINGB BIGINT NOT NULL,
    NumContainers INTEGER NOT NULL,
    CatJVMMaxSize BIGINT NOT NULL,
    ContJVMMaxSize BIGINT NOT NULL,
    USEDPORTS VARCHAR(800),
    JMXConnectionCacheSize INTEGER NOT NULL,
    GridConnectionCacheSize INTEGER NOT NULL,
    Created BIGINT NOT NULL,
    Updated BIGINT NOT NULL 
);

CREATE TABLE Members (
    ID BIGINT PRIMARY KEY GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1), 
    Name VARCHAR(64) NOT NULL UNIQUE, 
    CollectiveName VARCHAR(64) NOT NULL, 
    HostName VARCHAR(128),
    PublicIP VARCHAR(128) NOT NULL,
    PrivateIP VARCHAR(128),
    IsCatalog BOOLEAN NOT NULL,
    IsMaster BOOLEAN,
    IsPrimary BOOLEAN,
    Created BIGINT NOT NULL,
    Updated BIGINT NOT NULL 
);

ALTER TABLE Members  
       ADD CONSTRAINT COLLECTIVENAME_FK 
       Foreign Key (CollectiveName)  
       REFERENCES Collective (Name);
       

CREATE TABLE MemberStatus (
    ID BIGINT PRIMARY KEY GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1),
    MemberName VARCHAR(64) NOT NULL UNIQUE,
    CurrentStatus VARCHAR(8) NOT NULL,
    Comments VARCHAR(100),
    LastUpdated BIGINT NOT NULL 
);

ALTER TABLE MemberStatus  
       ADD CONSTRAINT MEMBER_NAME_FK 
       Foreign Key (MemberName)  
       REFERENCES Members (Name);   

       
CREATE TABLE Containers (
    ID BIGINT PRIMARY KEY GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1), 
    Name VARCHAR(255) NOT NULL UNIQUE, 
    JMXPort INTEGER NOT NULL,
    MemberName VARCHAR(64) NOT NULL
);

ALTER TABLE Containers  
       ADD CONSTRAINT CONTAINER_MEMBER_NAME_FK 
       Foreign Key (MemberName)  
       REFERENCES Members (Name);     
         
       
       
CREATE TABLE PortPools (
    Name VARCHAR(64) NOT NULL UNIQUE, 
    PeerPortPool  CLOB NOT NULL,
    XIOPortPool   CLOB NOT NULL,
    JMXPortPool   CLOB NOT NULL
);


insert into PortPools (Name, PeerPortPool, XIOPortPool, JMXPortPool) values ('WXSPortPools', '[6601,6602,6603,6604,6605,6606,6607,6608,6609,6610,6611,6612,6613,6614,6615,6616,6617,6618,6619,6620,6621,6622,6623,6624,6625,6626,6627,6628,6629,6630,6631,6632,6633,6634,6635,6636,6637,6638,6639,6640,6641,6642,6643,6644,6645,6646,6647,6648,6649,6650,6651,6652,6653,6654,6655,6656,6657,6658,6659,6660,6661,6662,6663,6664,6665,6666,6667,6668,6669,6670,6671,6672,6673,6674,6675,6676,6677,6678,6679,6680]', '[4809,4810,4811,4812,4813,4814,4815,4816,4817,4818,4819,4820,4821,4822,4823,4824,4825,4826,4827,4828,4829,4830,4831,4832,4833,4834,4835,4836,4837,4838,4839,4840,4841,4842,4843,4844,4845,4846,4847,4848]', '[1099,1100,1101,1102,1103,1104,1105,1106,1107,1108,1109,1110,1111,1112,1113,1114,1115,1116,1117,1118,1119,1120,1121,1122,1123,1124,1125,1126,1127,1128,1129,1130,1131,1132,1133,1134,1135,1136,1137,1138,1139,1140,1141,1142,1143,1144,1145,1146,1147,1148,1149,1150,1151,1152,1153,1154,1155,1156,1157,1158,1159,1160,1161,1162,1163,1164,1165,1166,1167,1168,1169,1170,1171,1172,1173,1174,1175,1176,1177,1178]');

insert into Collective(Name, Type, MAXCAPONMEMBERINGB, NumContainers, CatJVMMaxSize, ContJVMMaxSize, JMXConnectionCacheSize, GridConnectionCacheSize, Created, Updated) values('eDomain', 'MultiGridProcess', 4, 2, 200, 500, 50, 50, 111111, 111111);

insert into Members (Name, CollectiveName, HostName, PublicIP, PrivateIP, IsCatalog, IsMaster, IsPrimary, Created, Updated) values ('eDomain1-1', 'eDomain', 'localhost', 'localhost', '127.0.0.1', true, true, true, 111111, 111111);

insert into MemberStatus(MemberName, CurrentStatus, Comments, LastUpdated) values ('eDomain1-1', 'Offline', 'is offline', 111111);

