CREATE TABLE Users (
    ID BIGINT PRIMARY KEY GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1), 
    UserName VARCHAR(64) NOT NULL UNIQUE, 
    Name VARCHAR(64) NOT NULL, 
    Email VARCHAR(128) NOT NULL, 
    Salt VARCHAR (128) FOR BIT DATA NOT NULL, 
    PasswordHash VARCHAR (128) FOR BIT DATA  NOT NULL,
    IsLdapUser SMALLINT NOT NULL DEFAULT 0 CHECK (IsLdapUser IN (0, 1)),
    CurrentStatus VARCHAR(8) NOT NULL,
    CurrentMessage VARCHAR(8),
    Created BIGINT NOT NULL,
    Updated BIGINT NOT NULL 
);

CREATE TABLE UserActivity (
    ID BIGINT PRIMARY KEY GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1), 
    UserName VARCHAR(64) NOT NULL UNIQUE, 
    LastLoginTimestamp TIMESTAMP NOT NULL,
    FailedLoginAttempt SMALLINT NOT NULL,
    LockedTimeStamp TIMESTAMP 
);

ALTER TABLE UserActivity  
       ADD CONSTRAINT USERS_FK 
       Foreign Key (UserName)  
       REFERENCES Users (UserName);
       
CREATE TABLE Groups (
	ID BIGINT PRIMARY KEY GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1),
    Name VARCHAR(64) NOT NULL UNIQUE,
    Description VARCHAR(128),
    OwnerName VARCHAR(64) NOT NULL,
    Created BIGINT NOT NULL, 
    Updated BIGINT NOT NULL
);

CREATE TABLE GroupsUsers (
	ID BIGINT PRIMARY KEY GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1),
    GroupName VARCHAR(64) NOT NULL,
    UserName VARCHAR(64) NOT NULL,
    Created BIGINT NOT NULL, 
    Updated BIGINT NOT NULL 
);

CREATE TABLE RoleMapping (
	ID BIGINT PRIMARY KEY GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1),
    RoleType VARCHAR(32) NOT NULL,
    MemberName VARCHAR(64) NOT NULL,
    IsGroup SMALLINT NOT NULL DEFAULT 0 CHECK (IsGroup IN (0, 1)),
    Created BIGINT NOT NULL,
    Updated BIGINT NOT NULL
);

CREATE TABLE AccessControls (
	ID BIGINT PRIMARY KEY GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1),
    ResourceName VARCHAR(64) NOT NULL, 
    ResourceType VARCHAR(32) NOT NULL,
    MemberName VARCHAR(64) NOT NULL,
    IsGroup SMALLINT NOT NULL DEFAULT 0 CHECK (IsGroup IN (0, 1)),
    Created BIGINT NOT NULL, 
    Updated BIGINT NOT NULL, 
    CanRead SMALLINT,
    CanWrite SMALLINT,
    CanDelete SMALLINT,
    CanExecute SMALLINT
);



insert into Users (userName, Name, Email, Salt, PasswordHash, CurrentStatus, Created, Updated) values ('xsadmin', 'xsadmin', 
'xsadmin@com', x'441ff7fbf0f0a4bc9b83d414479e8fe8f2c712859d6c6548a209256772721ab6', x'efb1332a3ea29e1ffd9613fa22a6e844', 
'Buildin', 10000, 10000);


insert into Groups (Name, Description, OwnerName, Created, Updated) values ('Administrator', 'Administrator 
Group', 'xsadmin', 1421256880, 1421256880);


insert into RoleMapping (RoleType, MemberName, IsGroup, Created, Updated) values ('Administrator', 'Administrator', 1,
10000, 10000);


insert into GroupsUsers (GroupName, UserName, Created, Updated) values ('Administrator', 'xsadmin', 10000, 10000);
