@setlocal
@echo off
@REM IBM Confidential OCO Source Material
@REM 5724-J34 (C) COPYRIGHT International Business Machines Corp. 2015
@REM The source code for this program is not published or otherwise divested
@REM of its trade secrets, irrespective of what has been deposited with the
@REM U.S. Copyright Office.
@REM
@REM

set wxsLoc=%~dp0
set installDir=%wxsLoc%\..

IF EXIST "%wxsLoc%\derby\scripts\wxsdb" (
	echo This member has already been configured.
	GOTO DONE
)

call "%wxsLoc%\exportCommons.bat"

@REM Check for JAVA_HOME 
IF "%didSetJava%"=="" (
	IF "%JAVA_HOME%"==""	(
		echo The JAVA_HOME environment variable must be set either in exportCommons.bat or as a System variable for this installation to succeed.
		GOTO DONE
	) 
	reg query "HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\Session Manager\Environment" /s | findstr /C:JAVA_HOME > nul && (
			echo JAVA_HOME is set as a system variable.
		) || (
			echo The JAVA_HOME environment variable must be set either in exportCommons.bat or as a System variable for this installation to succeed.
			GOTO DONE
		)
	)
)

@REM check the parameters first
IF "%1"=="" GOTO USAGE
IF "%2"=="" GOTO USAGE
IF "%3"=="" GOTO USAGE
IF "%6"=="" GOTO USAGE

echo %3|findstr /xr "[1-9][0-9]* 0" >nul && (
  echo Cache group name is %1 and the capacity size for each member in the cache group is set to be %3 GB.
) || (
  echo Capacity size %3 is NOT a valid number
  GOTO USAGE
)

@REM Check user input seckey and xsadminPass
echo Validate user inputs...

set secretKey=%4
set xsadminPassword=%5
set encoded=%6

cd %installDir%\wlp\startscripts
call validateUserInput.bat secretKey xsadminPassword encoded

IF "%exitcode%"=="0" (
  echo %exitcode%
) ELSE (
  echo Failed to valid secret_key and xsadmin password changes... Start member process failed. 
  GOTO USAGE
)

@REM Copy file contents from migration folder to the install dir if not there yet
IF exist  "%installDir%\wlp\etc\jvm.options" (
  echo Skipping the copy files from the migration folder ...
) ELSE (
  echo  Copying file contents from the migration folder to the install folders...
  xcopy /y "%installDir%\migration\wlp\*"  "%installDir%\wlp"  /s
)

@REM ==================
@REM Loading DB schema
@REM ==================
echo Loading schema ...
cd %wxsLoc%\derby\scripts
call setupDerby.bat

@REM Exit if couldn't connect to database
IF %ERRORLEVEL% EQU 1 GOTO DONE

@REM ==============================
@REM update schema owner password
@REM ==============================
echo Verifying if this is an initial deployment ...

IF exist dbPwdUpdate.flg ( 
  echo Generating schema owner credentials and client access configuration ...
  call modifyCred.bat
  echo remove DB pwd update flg
  erase dbPwdUpdate.flg
)ELSE ( 
  echo  DB files exist, skipping of updating credentials. 
)


@REM =======================================
@REM Register cacheGroup/member information
@REM =======================================
echo Registering cache group and member information ...
call registerCollective.bat %1  %2  %3  secretKey xsadminPassword encoded


cd %installDir%\wlp\startscripts

@REM **************************************
@REM Create default servers for multi-grids
@REM **************************************
@echo Creating Default Grid Servers......
call createDefaultServers.bat

@REM **************************************
@REM Start default servers for multi-grids
@REM **************************************
@REM @echo Starting Default Grid Servers......
@REM call startDefaultGridServers.bat

@REM Stop derby and finish install if not admin user
net session >nul 2>&1
IF %ERRORLEVEL% NEQ 0 (
	cd "%installDir%\wxs\derby\scripts"
	stopNetWorkServer.bat
	GOTO DONE
)

@REM **************************************
@REM Start Nanny watch dog 
@REM **************************************
echo "Installing Nanny Watchdog."
cd "%installDir%\wlp\startscripts\nanny"
call installStartWatchDog.bat
@REM start /MIN "XS Nanny Watchdog" watchDog.bat

cd %wxsLoc%



GOTO DONE



:USAGE
echo [Usage]: startXSMember [CacheGroupName] [memberName] [memberCapInGB] [secretKey] [xsadminPassword] [encoded]
echo [Usage example]: startXSMember ecaas1  ecaas1-1  1  "myPass0rd4Me"  "myPass0rd4Me"  false
echo [Usage details]: The XS member starter command needs to have 6 parameters, the cache group name, the member name, the capacity size in GB on the member in this cache group, the secret_key, xsadmin updated password and encoded flag to indicate if the secret_key and xsadmin password are encoded or not.

:DONE
@endlocal
