CREATE TABLE Grids (
    ID BIGINT PRIMARY KEY GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1), 
    GridName VARCHAR(64) NOT NULL UNIQUE, 
    GridType VARCHAR(12) NOT NULL, 
    Owner VARCHAR(64) NOT NULL,
    Description VARCHAR(128),
    GridDeployment CLOB NOT NULL,
    GridTemplateName VARCHAR(64) NOT NULL,
    ObjectGrid CLOB NOT NULL,
    XIOPort INTEGER,
    JMXPort INTEGER,
    USEDPORTS VARCHAR(300),
    GRIDCAPINMB BIGINT,
    CurrentStatus VARCHAR(8) NOT NULL,
    Created BIGINT NOT NULL,
    Updated BIGINT NOT NULL 
);

CREATE TABLE GridTemplates (
    ID BIGINT PRIMARY KEY GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1), 
    Name VARCHAR(64) NOT NULL UNIQUE,
    GridType VARCHAR(12) NOT NULL,
    IsCustom SMALLINT NOT NULL DEFAULT 1 CHECK (IsCustom IN (0, 1)),
    Description VARCHAR(128),
    ObjectGrid CLOB NOT NULL,
    Deployment CLOB NOT NULL,
    Created BIGINT NOT NULL,
    Updated BIGINT NOT NULL 
);


ALTER TABLE Grids  
       ADD CONSTRAINT GRIDTEMPLATENAME_FK 
       Foreign Key (GridTemplateName)  
       REFERENCES GridTemplates (Name);

CREATE TABLE Exports (
    ID BIGINT PRIMARY KEY GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1), 
    ExportName VARCHAR(64) NOT NULL UNIQUE, 
    Path VARCHAR(64) NOT NULL,
    FileName VARCHAR(64) NOT NULL,
    Created BIGINT NOT NULL
);

insert into GridTemplates (Name, GridType, Description, IsCustom, ObjectGrid, Deployment, Created, Updated) values ('Simple', 'Simple', 'simple grid template for ECaaS', 0, '<?xml version="1.0" encoding="UTF-8"?><objectGridConfig xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://ibm.com/ws/objectgrid/config ../objectGrid.xsd" xmlns="http://ibm.com/ws/objectgrid/config"><objectGrids><objectGrid name="Simple" txTimeout="30" maxCapacity="500" securityEnabled="true" authorizationMechanism="AUTHORIZATION_MECHANISM_CUSTOM" ><bean id="ObjectGridAuthorization" className="com.ibm.ws.xs.tenant.security.auth.WXSAuthorizer" /><backingMap name="Simple" readOnly="false" lockStrategy="NONE" ttlEvictorType="NONE" timeToLive="0" copyMode="COPY_TO_BYTES" /><backingMap name=".*\.CT" template="true" readOnly="false" lockStrategy="NONE" ttlEvictorType="CREATION_TIME" timeToLive="3600" copyMode="COPY_TO_BYTES" /><backingMap name=".*\.LAT" template="true" readOnly="false" lockStrategy="NONE" ttlEvictorType="LAST_ACCESS_TIME" timeToLive="3600" copyMode="COPY_TO_BYTES" /><backingMap name=".*\.LUT" template="true" readOnly="false" lockStrategy="NONE" ttlEvictorType="LAST_UPDATE_TIME" timeToLive="3600" copyMode="COPY_TO_BYTES" /><backingMap name=".*\.NONE" template="true" readOnly="false" lockStrategy="NONE" ttlEvictorType="NONE" copyMode="COPY_TO_BYTES" /><backingMap name=".*\.CT\.P" template="true" readOnly="false" lockTimeout="15" lockStrategy="PESSIMISTIC" ttlEvictorType="CREATION_TIME" timeToLive="3600" copyMode="COPY_TO_BYTES" /><backingMap name=".*\.LAT\.P" template="true" readOnly="false" lockTimeout="15" lockStrategy="PESSIMISTIC" ttlEvictorType="LAST_ACCESS_TIME" timeToLive="3600" copyMode="COPY_TO_BYTES" /><backingMap name=".*\.LUT\.P" template="true" readOnly="false" lockTimeout="15" lockStrategy="PESSIMISTIC" ttlEvictorType="LAST_UPDATE_TIME" timeToLive="3600" copyMode="COPY_TO_BYTES" /><backingMap name=".*\.NONE\.P" template="true" readOnly="false" lockTimeout="15" lockStrategy="PESSIMISTIC" ttlEvictorType="NONE" copyMode="COPY_TO_BYTES" /><backingMap name=".*\.CT\.O" template="true" readOnly="false" lockTimeout="15" lockStrategy="OPTIMISTIC" ttlEvictorType="CREATION_TIME" timeToLive="3600" copyMode="COPY_TO_BYTES" pluginCollectionRef="NOVER" /><backingMap name=".*\.LAT\.O" template="true" readOnly="false" lockTimeout="15" lockStrategy="OPTIMISTIC" ttlEvictorType="LAST_ACCESS_TIME" timeToLive="3600" copyMode="COPY_TO_BYTES" pluginCollectionRef="NOVER" /><backingMap name=".*\.LUT\.O" template="true" readOnly="false" lockTimeout="15" lockStrategy="OPTIMISTIC" ttlEvictorType="LAST_UPDATE_TIME" timeToLive="3600" copyMode="COPY_TO_BYTES" pluginCollectionRef="NOVER" /><backingMap name=".*\.NONE\.O" template="true" readOnly="false" lockTimeout="15" lockStrategy="OPTIMISTIC" ttlEvictorType="NONE" copyMode="COPY_TO_BYTES" pluginCollectionRef="NOVER" /><backingMap name="Simple.NCI" readOnly="false" lockStrategy="NONE" nearCacheInvalidationEnabled="true" ttlEvictorType="NONE" timeToLive="0" copyMode="COPY_TO_BYTES"  /><backingMap name=".*\.CT\.NCI" template="true" readOnly="false" lockStrategy="NONE" nearCacheInvalidationEnabled="true" ttlEvictorType="CREATION_TIME" timeToLive="3600" copyMode="COPY_TO_BYTES" /><backingMap name=".*\.LAT\.NCI" template="true" readOnly="false" lockStrategy="NONE" nearCacheInvalidationEnabled="true" ttlEvictorType="LAST_ACCESS_TIME" timeToLive="3600" copyMode="COPY_TO_BYTES" /><backingMap name=".*\.LUT\.NCI" template="true" readOnly="false" lockStrategy="NONE" nearCacheInvalidationEnabled="true" ttlEvictorType="LAST_UPDATE_TIME" timeToLive="3600" copyMode="COPY_TO_BYTES" /><backingMap name=".*\.NONE\.NCI" template="true" readOnly="false" lockStrategy="NONE" nearCacheInvalidationEnabled="true" ttlEvictorType="NONE" copyMode="COPY_TO_BYTES" /><backingMap name=".*\.CT\.O\.NCI" template="true" readOnly="false" lockTimeout="15" lockStrategy="OPTIMISTIC" nearCacheInvalidationEnabled="true" ttlEvictorType="CREATION_TIME" timeToLive="3600" copyMode="COPY_TO_BYTES" pluginCollectionRef="NOVER" /><backingMap name=".*\.LAT\.O\.NCI" template="true" readOnly="false" lockTimeout="15" lockStrategy="OPTIMISTIC" nearCacheInvalidationEnabled="true" ttlEvictorType="LAST_ACCESS_TIME" timeToLive="3600" copyMode="COPY_TO_BYTES" pluginCollectionRef="NOVER" /><backingMap name=".*\.LUT\.O\.NCI" template="true" readOnly="false" lockTimeout="15" lockStrategy="OPTIMISTIC" nearCacheInvalidationEnabled="true" ttlEvictorType="LAST_UPDATE_TIME" timeToLive="3600" copyMode="COPY_TO_BYTES" pluginCollectionRef="NOVER" /><backingMap name=".*\.NONE\.O\.NCI" template="true" readOnly="false" lockTimeout="15" lockStrategy="OPTIMISTIC" nearCacheInvalidationEnabled="true" ttlEvictorType="NONE" copyMode="COPY_TO_BYTES" pluginCollectionRef="NOVER" /><backingMap name="IBM_WXS_GLOBAL_INDEX_.*" template="true" lockTimeout="15" lockStrategy="PESSIMISTIC" copyMode="COPY_TO_BYTES" /></objectGrid></objectGrids><backingMapPluginCollections><backingMapPluginCollection id="NOVER"><bean id="OptimisticCallback" className="com.ibm.websphere.objectgrid.plugins.builtins.NoVersioningOptimisticCallback" /></backingMapPluginCollection></backingMapPluginCollections></objectGridConfig>', '<?xml version="1.0" encoding="UTF-8"?><deploymentPolicy xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://ibm.com/ws/objectgrid/deploymentPolicy ../deploymentPolicy.xsd" xmlns="http://ibm.com/ws/objectgrid/deploymentPolicy"><objectgridDeployment objectgridName="Simple"><mapSet name="mapSet" numberOfPartitions="83" minSyncReplicas="0" maxSyncReplicas="0" maxAsyncReplicas="1" developmentMode="false" placementStrategy="FIXED_PARTITIONS"><map ref="Simple"/><map ref=".*\.CT"/><map ref=".*\.LUT"/><map ref=".*\.LAT"/><map ref=".*\.NONE"/><map ref=".*\.CT\.O"/><map ref=".*\.LUT\.O"/><map ref=".*\.LAT\.O"/><map ref=".*\.NONE\.O"/><map ref=".*\.CT\.P"/><map ref=".*\.LUT\.P"/><map ref=".*\.LAT\.P"/><map ref=".*\.NONE\.P"/><map ref="Simple.NCI"/><map ref=".*\.CT\.O\.NCI"/><map ref=".*\.LUT\.O\.NCI"/><map ref=".*\.LAT\.O\.NCI"/><map ref=".*\.NONE\.O\.NCI"/><map ref=".*\.CT\.NCI"/><map ref=".*\.LUT\.NCI"/><map ref=".*\.LAT\.NCI"/><map ref=".*\.NONE\.NCI"/><map ref="IBM_WXS_GLOBAL_INDEX_.*" /></mapSet></objectgridDeployment></deploymentPolicy>' ,10000, 10000);

insert into GridTemplates (Name, GridType, Description, IsCustom, ObjectGrid, Deployment, Created, Updated) values ('Session', 'Session', 'session grid template for ECaaS', 0, '<?xml version="1.0" encoding="UTF-8"?><objectGridConfig xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://ibm.com/ws/objectgrid/config ../objectGrid.xsd" xmlns="http://ibm.com/ws/objectgrid/config"><objectGrids><objectGrid name="Session" txTimeout="30" maxCapacity="500" securityEnabled="true" authorizationMechanism="AUTHORIZATION_MECHANISM_CUSTOM"><bean id="ObjectGridAuthorization" className="com.ibm.ws.xs.tenant.security.auth.WXSAuthorizer" /><bean id="ObjectGridEventListener" className="com.ibm.ws.xs.sessionmanager.SessionHandleManager"/><backingMap name="objectgridSessionMetadata" pluginCollectionRef="objectgridSessionMetadata" readOnly="false" lockTimeout="15" lockStrategy="PESSIMISTIC" ttlEvictorType="LAST_ACCESS_TIME" timeToLive="3600" copyMode="COPY_TO_BYTES"/><backingMap name="objectgridSessionAttribute.*" template="true" readOnly="false" lockTimeout="15" lockStrategy="PESSIMISTIC" ttlEvictorType="NONE" copyMode="COPY_TO_BYTES"/><backingMap name="objectgridSessionTTL.*" template="true" readOnly="false" lockTimeout="15" lockStrategy="PESSIMISTIC" ttlEvictorType="LAST_ACCESS_TIME" timeToLive="3600" copyMode="COPY_TO_BYTES"/><backingMap name="ASPNET.SessionState.*" template="true" readOnly="false" lockTimeout="15" lockStrategy="PESSIMISTIC" ttlEvictorType="LAST_ACCESS_TIME" timeToLive="3600" copyMode="COPY_TO_BYTES"/></objectGrid></objectGrids><backingMapPluginCollections><backingMapPluginCollection id="objectgridSessionMetadata"><bean id="MapEventListener" className="com.ibm.ws.xs.sessionmanager.MetadataMapListener"/></backingMapPluginCollection></backingMapPluginCollections></objectGridConfig>', '<?xml version="1.0" encoding="UTF-8"?><deploymentPolicy xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://ibm.com/ws/objectgrid/deploymentPolicy ../deploymentPolicy.xsd" xmlns="http://ibm.com/ws/objectgrid/deploymentPolicy"><objectgridDeployment objectgridName="Session"><mapSet name="sessionMapSet" numberOfPartitions="83" minSyncReplicas="0" maxSyncReplicas="0" maxAsyncReplicas="1" developmentMode="false" placementStrategy="FIXED_PARTITIONS"><map ref="objectgridSessionMetadata"/><map ref="objectgridSessionAttribute.*"/><map ref="objectgridSessionTTL.*"/><map ref="ASPNET.SessionState.*"/></mapSet></objectgridDeployment></deploymentPolicy>', 10000, 10000);

insert into GridTemplates (Name, GridType, Description, IsCustom, ObjectGrid, Deployment, Created, Updated) values ('Dynacache', 'DynaCache', 'DynaCache grid template with security and authorization enabled', 0, '<?xml version="1.0" encoding="UTF-8"?><objectGridConfig xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://ibm.com/ws/objectgrid/config ../objectGrid.xsd" xmlns="http://ibm.com/ws/objectgrid/config"><objectGrids><objectGrid name="DynaCache" txTimeout="30" maxCapacity="500" securityEnabled="true" authorizationMechanism="AUTHORIZATION_MECHANISM_CUSTOM"><bean id="ObjectGridAuthorization" className="com.ibm.ws.xs.tenant.security.auth.WXSAuthorizer" /><backingMap name="IBM_DC_XDF_PARTITIONED_.*" template="true" readOnly="false" pluginCollectionRef="all" preloadMode="false" lockTimeout="15" lockStrategy="PESSIMISTIC" copyMode="COPY_TO_BYTES" ttlEvictorType="NONE" nullValuesSupported="false" /><backingMap name="IBM_DC_XDF_NCI_PARTITIONED_.*" template="true" readOnly="false" pluginCollectionRef="allPlusNoVersionCallback" preloadMode="false" lockTimeout="15" lockStrategy="OPTIMISTIC" nearCacheInvalidationEnabled="true" nearCacheLastAccessTTLSyncEnabled="true" copyMode="COPY_TO_BYTES" ttlEvictorType="NONE" nullValuesSupported="false" /><backingMap name="IBM_DC_XDF_NGI_PARTITIONED_.*" template="true" readOnly="false" pluginCollectionRef="all_NoGlobalIndex" preloadMode="false" lockTimeout="15" lockStrategy="PESSIMISTIC" copyMode="COPY_TO_BYTES" ttlEvictorType="NONE" nullValuesSupported="false" /><backingMap name="IBM_DC_XDF_NCI_NGI_PARTITIONED_.*" template="true" readOnly="false" pluginCollectionRef="allPlusNoVersionCallback_NoGlobalIndex" preloadMode="false" lockTimeout="15" lockStrategy="OPTIMISTIC" nearCacheInvalidationEnabled="true" nearCacheLastAccessTTLSyncEnabled="true" copyMode="COPY_TO_BYTES" ttlEvictorType="NONE" nullValuesSupported="false" /><backingMap name="IBM_DC_PARTITIONED_.*" template="true" readOnly="false" pluginCollectionRef="all" preloadMode="false" lockTimeout="15" lockStrategy="PESSIMISTIC" copyMode="COPY_ON_READ_AND_COMMIT" ttlEvictorType="NONE" nullValuesSupported="false" /><backingMap name="IBM_DC_NCI_PARTITIONED_.*" template="true" readOnly="false" pluginCollectionRef="allPlusNoVersionCallback" preloadMode="false" lockTimeout="15" lockStrategy="OPTIMISTIC" nearCacheInvalidationEnabled="true" nearCacheLastAccessTTLSyncEnabled="true" copyMode="COPY_ON_READ_AND_COMMIT" ttlEvictorType="NONE" nullValuesSupported="false" /><backingMap name="IBM_DC_NGI_PARTITIONED_.*" template="true" readOnly="false" pluginCollectionRef="all_NoGlobalIndex" preloadMode="false" lockTimeout="15" lockStrategy="PESSIMISTIC" copyMode="COPY_ON_READ_AND_COMMIT" ttlEvictorType="NONE" nullValuesSupported="false" /><backingMap name="IBM_DC_NCI_NGI_PARTITIONED_.*" template="true" readOnly="false" pluginCollectionRef="allPlusNoVersionCallback_NoGlobalIndex" preloadMode="false" lockTimeout="15" lockStrategy="OPTIMISTIC" nearCacheInvalidationEnabled="true" nearCacheLastAccessTTLSyncEnabled="true" copyMode="COPY_ON_READ_AND_COMMIT" ttlEvictorType="NONE" nullValuesSupported="false" /><backingMap name="IBM_WXS_GLOBAL_INDEX_.*" template="true" lockTimeout="15" lockStrategy="PESSIMISTIC" copyMode="COPY_TO_BYTES" ><customProperty name="IBM_SYSTEM_WXS.INTERNAL" value="true"/></backingMap></objectGrid></objectGrids><backingMapPluginCollections><backingMapPluginCollection id="all"><bean id="MapIndexPlugin" className="com.ibm.websphere.objectgrid.plugins.index.HashIndex"><property name="Name" type="java.lang.String" value="DEPENDENCY_ID_INDEX" description="index name" /><property name="RangeIndex" type="boolean" value="false" description="true for MapRangeIndex" /><property name="AttributeName" type="java.lang.String" value="dependencies" description="attribute name" /><property name="GlobalIndexEnabled" type="boolean" value="true" description="required to enable global index" /><property name="FieldAccessAttribute" type="boolean" value="true" description="access the fields rather than getters" /></bean><bean id="MapIndexPlugin" className="com.ibm.websphere.objectgrid.plugins.index.HashIndex"><property name="Name" type="java.lang.String" value="TEMPLATE_INDEX" description="index name" /><property name="RangeIndex" type="boolean" value="false" description="true for MapRangeIndex" /><property name="AttributeName" type="java.lang.String" value="templates" description="attribute name" /><property name="GlobalIndexEnabled" type="boolean" value="true"	description="required to enable global index" /><property name="FieldAccessAttribute" type="boolean" value="true" description="access the fields rather than getters" /></bean><bean id="ObjectTransformer" className="com.ibm.ws.objectgrid.dynacache.entries.CacheEntryData$Transformer" /><bean id="Evictor" className="com.ibm.ws.objectgrid.dynacache.evictors.DistributedDynacacheEvictor"/><bean id="Loader" className="com.ibm.ws.objectgrid.dynacache.DynacacheLoader"/></backingMapPluginCollection><backingMapPluginCollection id="allPlusNoVersionCallback"><bean id="MapIndexPlugin" className="com.ibm.websphere.objectgrid.plugins.index.HashIndex"><property name="Name" type="java.lang.String" value="DEPENDENCY_ID_INDEX" description="index name" /><property name="RangeIndex" type="boolean" value="false" description="true for MapRangeIndex" /><property name="AttributeName" type="java.lang.String" value="dependencies" description="attribute name" /><property name="GlobalIndexEnabled" type="boolean" value="true" description="required to enable global index" /><property name="FieldAccessAttribute" type="boolean" value="true" description="access the fields rather than getters" /></bean><bean id="MapIndexPlugin" className="com.ibm.websphere.objectgrid.plugins.index.HashIndex"><property name="Name" type="java.lang.String" value="TEMPLATE_INDEX" description="index name" /><property name="RangeIndex" type="boolean" value="false" description="true for MapRangeIndex" /><property name="AttributeName" type="java.lang.String" value="templates" description="attribute name" /><property name="GlobalIndexEnabled" type="boolean" value="true"	description="required to enable global index" /><property name="FieldAccessAttribute" type="boolean" value="true" description="access the fields rather than getters" /></bean><bean id="ObjectTransformer" className="com.ibm.ws.objectgrid.dynacache.entries.CacheEntryData$Transformer" /><bean id="Evictor" className="com.ibm.ws.objectgrid.dynacache.evictors.DistributedDynacacheEvictor"/><bean id="Loader" className="com.ibm.ws.objectgrid.dynacache.DynacacheLoader"/><bean id="OptimisticCallback" className="com.ibm.websphere.objectgrid.plugins.builtins.NoVersioningOptimisticCallback" /></backingMapPluginCollection><backingMapPluginCollection id="all_NoGlobalIndex"><bean id="MapIndexPlugin" className="com.ibm.websphere.objectgrid.plugins.index.HashIndex"><property name="Name" type="java.lang.String" value="DEPENDENCY_ID_INDEX" description="index name" /><property name="RangeIndex" type="boolean" value="false" description="true for MapRangeIndex" /><property name="AttributeName" type="java.lang.String" value="dependencies" description="attribute name" /><property name="GlobalIndexEnabled" type="boolean" value="false" description="required to enable global index" /><property name="FieldAccessAttribute" type="boolean" value="true" description="access the fields rather than getters" /></bean><bean id="MapIndexPlugin" className="com.ibm.websphere.objectgrid.plugins.index.HashIndex"><property name="Name" type="java.lang.String" value="TEMPLATE_INDEX" description="index name" /><property name="RangeIndex" type="boolean" value="false" description="true for MapRangeIndex" /><property name="AttributeName" type="java.lang.String" value="templates" description="attribute name" /><property name="GlobalIndexEnabled" type="boolean" value="false"	description="required to enable global index" /><property name="FieldAccessAttribute" type="boolean" value="true" description="access the fields rather than getters" /></bean><bean id="ObjectTransformer" className="com.ibm.ws.objectgrid.dynacache.entries.CacheEntryData$Transformer" /><bean id="Evictor" className="com.ibm.ws.objectgrid.dynacache.evictors.DistributedDynacacheEvictor"/><bean id="Loader" className="com.ibm.ws.objectgrid.dynacache.DynacacheLoader"/></backingMapPluginCollection><backingMapPluginCollection id="allPlusNoVersionCallback_NoGlobalIndex"><bean id="MapIndexPlugin" className="com.ibm.websphere.objectgrid.plugins.index.HashIndex"><property name="Name" type="java.lang.String" value="DEPENDENCY_ID_INDEX" description="index name" /><property name="RangeIndex" type="boolean" value="false" description="true for MapRangeIndex" /><property name="AttributeName" type="java.lang.String" value="dependencies" description="attribute name" /><property name="GlobalIndexEnabled" type="boolean" value="false" description="required to enable global index" /><property name="FieldAccessAttribute" type="boolean" value="true" description="access the fields rather than getters" /></bean><bean id="MapIndexPlugin" className="com.ibm.websphere.objectgrid.plugins.index.HashIndex"><property name="Name" type="java.lang.String" value="TEMPLATE_INDEX" description="index name" /><property name="RangeIndex" type="boolean" value="false" description="true for MapRangeIndex" /><property name="AttributeName" type="java.lang.String" value="templates" description="attribute name" /><property name="GlobalIndexEnabled" type="boolean" value="false"	description="required to enable global index" /><property name="FieldAccessAttribute" type="boolean" value="true" description="access the fields rather than getters" /></bean><bean id="ObjectTransformer" className="com.ibm.ws.objectgrid.dynacache.entries.CacheEntryData$Transformer" /><bean id="Evictor" className="com.ibm.ws.objectgrid.dynacache.evictors.DistributedDynacacheEvictor"/><bean id="Loader" className="com.ibm.ws.objectgrid.dynacache.DynacacheLoader"/><bean id="OptimisticCallback" className="com.ibm.websphere.objectgrid.plugins.builtins.NoVersioningOptimisticCallback" /></backingMapPluginCollection></backingMapPluginCollections></objectGridConfig>', '<?xml version="1.0" encoding="UTF-8"?><deploymentPolicy xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://ibm.com/ws/objectgrid/deploymentPolicy ../deploymentPolicy.xsd" xmlns="http://ibm.com/ws/objectgrid/deploymentPolicy"><objectgridDeployment objectgridName="DynaCache"><mapSet name="DYNACACHE_REMOTE" numberOfPartitions="83" minSyncReplicas="0" maxSyncReplicas="0" maxAsyncReplicas="1" numInitialContainers="1" developmentMode="false" replicaReadEnabled="false"><map ref="IBM_DC_XDF_PARTITIONED_.*" /><map ref="IBM_DC_XDF_NCI_PARTITIONED_.*" /><map ref="IBM_DC_XDF_NGI_PARTITIONED_.*" /><map ref="IBM_DC_XDF_NCI_NGI_PARTITIONED_.*" /><map ref="IBM_DC_PARTITIONED_.*" /><map ref="IBM_DC_NCI_PARTITIONED_.*" /><map ref="IBM_DC_NGI_PARTITIONED_.*" /><map ref="IBM_DC_NCI_NGI_PARTITIONED_.*" /><map ref="IBM_WXS_GLOBAL_INDEX_.*" /></mapSet></objectgridDeployment></deploymentPolicy>', 10000, 10000);
